<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>OutputWaveOutFactory</name>
    <message>
        <location filename="../outputwaveoutfactory.cpp" line="30"/>
        <source>WaveOut Plugin</source>
        <translation>WaveOut プラグイン</translation>
    </message>
    <message>
        <location filename="../outputwaveoutfactory.cpp" line="54"/>
        <source>About WaveOut Output Plugin</source>
        <translation>WaveOut 出力プラグインについて</translation>
    </message>
    <message>
        <location filename="../outputwaveoutfactory.cpp" line="55"/>
        <source>Qmmp WaveOut Output Plugin</source>
        <translation>QMMP WaveOut 出力プラグイン</translation>
    </message>
    <message>
        <location filename="../outputwaveoutfactory.cpp" line="56"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../outputwaveoutfactory.cpp" line="57"/>
        <source>Based on aacDECdrop player</source>
        <translation>aacDECdrop プレイヤを基に作成</translation>
    </message>
</context>
</TS>
